@@ -11,13 +11,15 @@ xewma.ad <- function(l,c,mu1,mu0=0,zr=0,sided="one",limits="fix",r=40) {
   ctyp <- pmatch(sided, c("one", "two")) - 1
   if (is.na(ctyp)) 
     stop("invalid ewma type")
-  ltyp <- pmatch(limits, c("fix","vacl","fir","both","Steiner","Knoth")) - 1
-  if (is.na(ltyp)) 
+  ltyp <- pmatch(limits, c("fix","vacl","fir","both","Steiner","stat")) - 1
+  if (is.na(ltyp))
     stop("invalid limits type")
+  if ( (sided=="one") & !(limits %in% c("fix", "vacl", "stat")) )
+    stop("not supported for one-sided EWMA (not reasonable or not implemented yet")
   ad <- .C("xewma_ad",as.integer(ctyp),as.double(l),
            as.double(c),as.double(zr),as.double(mu0),as.double(mu1),
            as.integer(ltyp),as.integer(r),
-           ans=double(length=1),,PACKAGE="spc")$ans 
+           ans=double(length=1),PACKAGE="spc")$ans 
   names(ad) <- "ad"
   return (ad)
 }
